==> poocr-1.0.2.tar.gz: poocr-1.0.2/README.md <==
<p align="center" id='大礼包-banner'>
    <a target="_blank" href='http://python4office.cn/fuli/fuli-source-0726/'>
    <img src="https://banner-1300615378.cos.ap-guangzhou.myqcloud.com/%E6%A8%AA%E6%9D%A1/Python%E5%A4%A7%E7%A4%BC%E5%8C%85.jpg" width="100%"/>
    </a>   
</p>



<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/">项目官网：https://www.python-office.com/</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="http://www.python4office.cn/wechat-group/">本开源项目的交流群</a> 👈
</p>


<p align="center" name="'github">
    <a target="_blank" href='https://github.com/CoderWanFeng/poocr'>
    <img src="https://img.shields.io/github/stars/CoderWanFeng/poocr.svg?style=social" alt="github star"/>
    </a>
	<a target="_blank" href='https://gitcode.com/CoderWanFeng1/python-office'>
		<img src='https://gitcode.com/CoderWanFeng1/python-office/star/badge.svg?theme=dark' alt='gitcode star'/>
	</a>	
    	<a target="_blank" href='https://gitee.com/CoderWanFeng//poocr/'>
		<img src='https://gitee.com/CoderWanFeng//poocr/badge/star.svg?theme=dark' alt='gitee star'/>
	</a>
  	<a href="https://mp.weixin.qq.com/s/yaSmFKO3RrBpyanW3nvRAQ">
	<img src="https://img.shields.io/badge/QQ-163434413-orange"/>
  </a>
    	<a href="http://www.python4office.cn/wechat-group/">
	<img src="https://img.shields.io/badge/%E5%BE%AE%E4%BF%A1-%E4%BA%A4%E6%B5%81%E7%BE%A4-brightgreen"/>
  </a>

</p>



-------------------------------------------------------------------------------

## 📚简介

poocr 是一个文字识别的第三方库。

- 💻所有功能的讲解👉[5讲OCR批量识别后自动保存为Excel，给小白的Python入门课又增加了！](https://www.bilibili.com/video/BV13J4m1s7L7/)

<p align="center" id='5讲OCR-banner'>
    <a target="_blank" href='https://www.python-office.com/course-002/5-poocr/5-poocr.html'>
    <img src="https://course-1300615378.cos.ap-guangzhou.myqcloud.com/poocr%2F%E5%B0%81%E9%9D%A2-%E6%A8%AA.jpg" width="100%"/>
    </a>   
</p>

-------------------------------------------------------------------------------

## 📦安装

### 🍊pip 自动下载&更新

#### 源码安装

```
git clone https://gitcode.com/python4office/poocr.git

cd poocr

pip install -e .
```

#### 源安装&更新

我使用的是阿里云镜像。如果你的网络环境无法访问阿里云镜像，请自行更换为其他镜像。

```
pip install -i https://mirrors.aliyun.com/pypi/simple/ poocr -U
```

-------------------------------------------------------------------------------

## 📝官网

- [📘Python自动化办公的官网👉https://www.python-office.com/](https://www.python-office.com/)

## 🏗️添砖加瓦

### 📐PR的建议

poocr欢迎任何人来添砖加瓦，贡献代码。

#### 目录结构和pr要求如下：

- docs：存放该项目的文档，包括教程、案例等。
- examples：存放该项目的案例，**如果你有新增功能或者接口，请在这里新建一个py文件，并在这里写一个使用案例。**
- poocr：存放该项目的源代码，其中：
    - api：提供外部调用的接口。
    - core：存放该项目的核心代码，包括类、函数等。
    - lib：存放工具类、工具函数等。
- tests：存放该项目的单元测试的代码，其中：
    - test_code：存放测试代码，**每新增/修改任一个函数，提交之前必须写单元测试**！
    - test)files：存放测试文件，包括图片、Excel等。
- README.md、requirement.txt、setup等文件，一般不修改。

### 🐞提供bug反馈或建议

提交问题反馈时，请务必填写和poocr代码本身有关的问题，不进行有关python学习，甚至是个人练习的知识答疑和讨论。

- [Github issue](https://github.com/CoderWanFeng/poocr/issues)
- [GitCode issue](https://gitcode.com/python4office/poocr/issues)
- [Gitee issue](https://gitee.com/CoderWanFeng/poocr/issues)

-------------------------------------------------------------------------------

## 📌联系作者

> 目前项目的核心开发者：[@wzllby](https://gitcode.com/wzllby)、[@null](https://gitcode.com/wangkaka)、[程序员晚枫](https://gitcode.com/CoderWanFeng1)

<p align="center" id='开源交流群-banner'>
<a target="_blank" href='https://cos.python-office.com/group%2Ffree-group.jpg'>
<img src="https://cos.python-office.com/group/python-office-qr.jpg" width="100%"/>
</a> 
</p>

==> poocr-1.0.6.tar.gz: poocr-1.0.6/README.md <==
<p align="center" id='大礼包-banner'>
    <a target="_blank" href='http://python4office.cn/fuli/fuli-source-0726/'>
    <img src="https://banner-1300615378.cos.ap-guangzhou.myqcloud.com/%E6%A8%AA%E6%9D%A1/Python%E5%A4%A7%E7%A4%BC%E5%8C%85.jpg" width="100%"/>
    </a>   
</p>



<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/">项目官网：https://www.python-office.com/</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="http://www.python4office.cn/wechat-group/">本开源项目的交流群</a> 👈
</p>


<p align="center" name="'github">
    <a target="_blank" href='https://github.com/CoderWanFeng/poocr'>
    <img src="https://img.shields.io/github/stars/CoderWanFeng/poocr.svg?style=social" alt="github star"/>
    </a>
	<a target="_blank" href='https://gitcode.com/CoderWanFeng1/python-office'>
		<img src='https://gitcode.com/CoderWanFeng1/python-office/star/badge.svg?theme=dark' alt='gitcode star'/>
	</a>	
    	<a target="_blank" href='https://gitee.com/CoderWanFeng//poocr/'>
		<img src='https://gitee.com/CoderWanFeng//poocr/badge/star.svg?theme=dark' alt='gitee star'/>
	</a>
  	<a href="https://mp.weixin.qq.com/s/yaSmFKO3RrBpyanW3nvRAQ">
	<img src="https://img.shields.io/badge/QQ-163434413-orange"/>
  </a>
    	<a href="http://www.python4office.cn/wechat-group/">
	<img src="https://img.shields.io/badge/%E5%BE%AE%E4%BF%A1-%E4%BA%A4%E6%B5%81%E7%BE%A4-brightgreen"/>
  </a>

</p>



-------------------------------------------------------------------------------

## 📚简介

poocr 是一个文字识别的第三方库。

- 💻所有功能的讲解👉[5讲OCR批量识别后自动保存为Excel，给小白的Python入门课又增加了！](https://www.python-office.com/course-002/5-poocr/5-poocr.html)

<p align="center" id='5讲OCR-banner'>
    <a target="_blank" href='https://www.python-office.com/course-002/5-poocr/5-poocr.html'>
    <img src="https://course-1300615378.cos.ap-guangzhou.myqcloud.com/poocr%2F%E5%B0%81%E9%9D%A2-%E6%A8%AA.jpg" width="100%"/>
    </a>   
</p>

-------------------------------------------------------------------------------

## 📦安装

### 🍊pip 自动下载&更新

#### 源码安装

```
git clone https://gitcode.com/python4office/poocr.git

cd poocr

pip install -e .
```

#### 源安装&更新

我使用的是阿里云镜像。如果你的网络环境无法访问阿里云镜像，请自行更换为其他镜像。

```
pip install -i https://mirrors.aliyun.com/pypi/simple/ poocr -U
```

-------------------------------------------------------------------------------

## 📝官网

- [📘Python自动化办公的官网👉https://www.python-office.com/](https://www.python-office.com/)

## 🏗️添砖加瓦

### 📐PR的建议

poocr欢迎任何人来添砖加瓦，贡献代码。

#### 目录结构和pr要求如下：

- docs：存放该项目的文档，包括教程、案例等。
- examples：存放该项目的案例，**如果你有新增功能或者接口，请在这里新建一个py文件，并在这里写一个使用案例。**
- poocr：存放该项目的源代码，其中：
    - api：提供外部调用的接口。
    - core：存放该项目的核心代码，包括类、函数等。
    - lib：存放工具类、工具函数等。
- tests：存放该项目的单元测试的代码，其中：
    - test_code：存放测试代码，**每新增/修改任一个函数，提交之前必须写单元测试**！
    - test)files：存放测试文件，包括图片、Excel等。
- README.md、requirement.txt、setup等文件，一般不修改。

### 🐞提供bug反馈或建议

提交问题反馈时，请务必填写和poocr代码本身有关的问题，不进行有关python学习，甚至是个人练习的知识答疑和讨论。

- [Github issue](https://github.com/CoderWanFeng/poocr/issues)
- [GitCode issue](https://gitcode.com/python4office/poocr/issues)
- [Gitee issue](https://gitee.com/CoderWanFeng/poocr/issues)

-------------------------------------------------------------------------------

## 📌联系作者

> 目前项目的核心开发者：[@wzllby](https://gitcode.com/wzllby)、[@null](https://gitcode.com/wangkaka)、[程序员晚枫](https://gitcode.com/CoderWanFeng1)

<p align="center" id='开源交流群-banner'>
<a target="_blank" href='https://cos.python-office.com/group%2Ffree-group.jpg'>
<img src="https://cos.python-office.com/group/python-office-qr.jpg" width="100%"/>
</a> 
</p>
